*--------------------------------------------------------------------------*;
%let ProgramName = smalltest ;
%let Extension   = sas ;
%let Version     = 3.5 ;
%let Root        = /data/cahpsmmc/analysis_program/version 3.5 ;
%let ProgramPath = /programs/ ;
%let Created     = 24 Aug 2005 ;
%let Author      = Matthew J. Cioffi ;
%let Type        = Program ;

*--------------------------------------------------------------------------*
| What are the required input data sets and macros needed by the program.  |
      MACROS: cahps35.sas
*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| What are the permanent output datasets created by the program or where   |
| are all the datasets stored if there are many.                           |
      The data sets created by the CAHPS macro.
*--------------------------------------------------------------------------*;
 
***********
* Purpose *
   Creates an eight record data set that can be used to easily follow
   the steps that the CAHPS macro takes.

*--------------------------------------------------------------------------*;
%let Updated  = dd-mmm-yyyy ;
%let By_Whom  = ;
**********
* Reason *

*--------------------------------------------------------------------------*;

*--------------------------------------------------------------------------*
| Macro Variables                                                          |
*--------------------------------------------------------------------------*;
%let Filename    = &ProgramName..&Extension  ; 

*--------------------------------------------------------------------------*
|  Library and Filename References                                         |
|     in       -  SAS data set to be used as input.                        |
|     out      -  Permanent SAS data sets created by Macro stored here.    |
|                   ** OUT is required by the CAHPS macro **               |
|     library  -  Location of the library for using permanent formats.     |
|                                                                          |
|     logfile  -  Path and filename for the SAS log file.                  |
|     outfile  -  Path and filename for storing SAS procedure output.      |
|     cahps    -  Path and filename for the CAHPS macro.                   |
*--------------------------------------------------------------------------*;

libname in        "&root./sasdata/" ;
libname out       "&root./sasdata/smalltest/" ;
libname library   "&root./sascatalog/" ;

filename _all_ clear ;
filename logfile  "&root./output/logs/&ProgramName..log" ;
filename outfile  "&root./output/&ProgramName..txt" ;
filename cahps    "&root./programs/cahps35.sas" ;


*--------------------------------------------------------------------------*
|   Print the output to a separate file                                    |
*--------------------------------------------------------------------------*;

proc printto print = outfile new
             log   = logfile new ;
run ;


*--------------------------------------------------------------------------*
|   Clear all titles and footnotes                                         |
*--------------------------------------------------------------------------*;

title ;
footnote ;

run ;

*--------------------------------------------------------------------------*
|  Macro Name : nowbox                                                     |
|  Usage      : %nowbox (logtext = Your text here)                         |
|  Purpose    :                                                            |
|     Assign the local variable &now the current system date and time      |
|     and place a time stamp line into the current log.                    |
*--------------------------------------------------------------------------*;

%macro nowbox (logtext= ** Time Stamp **) ;
   %local now ;
   %let now = %sysfunc(date(),worddatx32.) at %sysfunc(time(),time9.) ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
   %put &logtext &now ;
   %put ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ;
%mend nowbox ;


%nowbox (logtext= Begin &FileName version &Version) ;

*--------------------------------------------------------------------------*
| Global Options Assigned Below                                            |
*--------------------------------------------------------------------------*;

options pagesize = 65
        linesize = 90
        pageno   = 1
        noovp
        nonumber
        nodate
        nomprint
        nomlogic
        ;
run ;


*--------------------------------------------------------------------------*
| Begin Preparation of data set for CAHPS macro                            |
*--------------------------------------------------------------------------*;

data smalltst ;
  input plan $ Q1 Q2 ADJ1 ADJ2 WGT ;
  visits = 1 ;
  child  = 0 ;
cards ;
A  2  4  1  1  40  
A  3  .  2  2  50 
A  4  2  3  .  6  
A  4  3  .  .  8  
A  3  3  2  3 10  
B  3  3  2  3  3  
B  .  .  4  5  5  
B  2  2  5  4  3  
B  3  2  6  3  5  
B  7  3  3  3  3  
;
run ;

*--------------------------------------------------------------------------*
| ** End Peparation of data set for CAHPS macro **                         |
*--------------------------------------------------------------------------*;


*--------------------------------------------------------------------------*
| Include and compile needed macros.                                       |
*--------------------------------------------------------------------------*;

%include cahps ;


%cahps(var      = q1 q2,
       vartype  = 3,
       name     = small test without adj,
       adjuster = ,
       adj_bars = 1,
       bar_stat = 1, 
       adultkid = 3,
       dataset  = smalltst,
       outname  = small_no_adj ) ;


%cahps(var      = q1 q2,
       vartype  = 3,
       name     = small test with adj,
       adjuster = adj1 adj2,
       adj_bars = 1,
       bar_stat = 1, 
       adultkid = 3,
       dataset  = smalltst,
       outname  = smadj_adj ) ;

%cahps(var      = q1 q2,
       vartype  = 3,
       name     = small test with adj,
       adjuster = adj1 adj2,
       adj_bars = 1,
       bar_stat = 1, 
       adultkid = 3,
       wgtresp  = wgt,
       wgtmean  = wgt,
       wgtplan  = 1,
       dataset  = smalltst,
       outname  = smadj_adj ) ;



%nowbox (logtext = End &FileName version &Version ) ;

*--------------------------------------------------------------------------*
|  Reset the log and output files back to the defaults                     |
*--------------------------------------------------------------------------*;

proc printto ;
run ;

filename _all_  clear ;
